==> dokuwiki-2013.05.10.tgz: dokuwiki/lib/plugins/usermanager/lang/eo/lang.php <==
<?php
/**
 * Esperantolanguage file
 *
 * @author Felipe Castro <fefcas@uol.com.br>
 * @author Felipe Castro <fefcas@gmail.com>
 * @author Felipe Castro <fefcas (cxe) gmail (punkto) com>
 * @author Felipo Kastro <fefcas@gmail.com>
 * @author Robert Bogenschneider <robog@gmx.de>
 * @author Erik Pedersen <erik pedersen@shaw.ca>
 * @author Erik Pedersen <erik.pedersen@shaw.ca>
 * @author Robert Bogenschneider <bogi@uea.org>
 */
$lang['menu']                  = 'Administrado de uzantoj';
$lang['noauth']                = '(identiĝo de uzantoj ne disponeblas)';
$lang['nosupport']             = '(administro de uzantoj ne estas subtenata)';
$lang['badauth']               = 'tiu identiĝa procezo ne validas';
$lang['user_id']               = 'Uzanto';
$lang['user_pass']             = 'Pasvorto';
$lang['user_name']             = 'Vera nomo';
$lang['user_mail']             = 'Retpoŝtadreso';
$lang['user_groups']           = 'Grupoj';
$lang['field']                 = 'Kampo';
$lang['value']                 = 'Valoro';
$lang['add']                   = 'Aldoni';
$lang['delete']                = 'Forigi';
$lang['delete_selected']       = 'Forigi elektitan';
$lang['edit']                  = 'Modifi';
$lang['edit_prompt']           = 'Modifi tiun ĉi uzanton';
$lang['modify']                = 'Registri modifojn';
$lang['search']                = 'Serĉi';
$lang['search_prompt']         = 'Fari serĉon';
$lang['clear']                 = 'Refari serĉan filtron';
$lang['filter']                = 'Filtro';
$lang['summary']               = 'Montriĝas uzantoj %1$d-%2$d el %3$d trovitaj. %4$d uzantoj entute.';
$lang['nonefound']             = 'Neniuj uzantoj troviĝas. %d uzantoj entute.';
$lang['delete_ok']             = '%d uzantoj forigiĝis';
$lang['delete_fail']           = '%d malsukcesis esti forigitaj.';
$lang['update_ok']             = 'Tiu uzanto sukcese ĝisdatiĝis';
$lang['update_fail']           = 'Malsukceso okazis por ĝisdatigi tiun uzanton';
$lang['update_exists']         = 'Malsukceso okazis por ŝanĝi la nomon de tiu uzanto: la enmetita nomo (%s) jam ekzistas (ĉiuj aliaj ŝanĝoj estos aplikitaj)';
$lang['start']                 = 'Ekigi';
$lang['prev']                  = 'antaŭe';
$lang['next']                  = 'sekve';
$lang['last']                  = 'laste';
$lang['edit_usermissing']      = 'La elektita uzanto ne troviĝis: tiu nomo povis esti forigita aŭ ŝanĝita aliloke.';
$lang['user_notify']           = 'Avizi uzanton';
$lang['note_notify']           = 'Avizantaj mesaĝoj estos sendataj nur se la uzanto ekhavos novan pasvorton.';
$lang['note_group']            = 'Novaj uzantoj estos aldonitaj al la komuna grupo (%s) se neniu alia estos specifita.';
$lang['note_pass']             = 'La pasvorto estos aŭtomate kreita se la kampo estos lasita malplena kaj \'avizo al uzantoj\' estos ebligita.';
$lang['add_ok']                = 'La uzanto sukcese aldoniĝis';
$lang['add_fail']              = 'Ne eblis aldoni uzanton';
$lang['notify_ok']             = 'Avizanta mesaĝo sendiĝis';
$lang['notify_fail']           = 'La avizanta mesaĝo ne povis esti sendita';

==> dokuwiki-2024.02.06p0.tgz: dokuwiki/lib/plugins/usermanager/lang/eo/lang.php <==
<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 *
 * @author Felipe Castro <fefcas@uol.com.br>
 * @author Felipo Kastro <fefcas@gmail.com>
 * @author Robert Bogenschneider <robog@gmx.de>
 * @author Erik Pedersen <erik pedersen@shaw.ca>
 */
$lang['menu']                  = 'Administrado de uzantoj';
$lang['noauth']                = '(identiĝo de uzantoj ne disponeblas)';
$lang['nosupport']             = '(administro de uzantoj ne estas subtenata)';
$lang['badauth']               = 'tiu identiĝa procezo ne validas';
$lang['user_id']               = 'Uzanto';
$lang['user_pass']             = 'Pasvorto';
$lang['user_name']             = 'Vera nomo';
$lang['user_mail']             = 'Retpoŝtadreso';
$lang['user_groups']           = 'Grupoj';
$lang['field']                 = 'Kampo';
$lang['value']                 = 'Valoro';
$lang['add']                   = 'Aldoni';
$lang['delete']                = 'Forigi';
$lang['delete_selected']       = 'Forigi elektitan';
$lang['edit']                  = 'Modifi';
$lang['edit_prompt']           = 'Modifi tiun ĉi uzanton';
$lang['modify']                = 'Registri modifojn';
$lang['search']                = 'Serĉi';
$lang['search_prompt']         = 'Fari serĉon';
$lang['clear']                 = 'Refari serĉan filtron';
$lang['filter']                = 'Filtro';
$lang['export_all']            = 'Eksporti ĉiujn uzantojn (CSV)';
$lang['export_filtered']       = 'Eksporti filtritan uzant-liston (CSV)';
$lang['import']                = 'Importi novajn uzantojn';
$lang['line']                  = 'Lini-num.';
$lang['error']                 = 'Erar-mesaĝo';
$lang['summary']               = 'Montriĝas uzantoj %1$d-%2$d el %3$d trovitaj. %4$d uzantoj entute.';
$lang['nonefound']             = 'Neniuj uzantoj troviĝas. %d uzantoj entute.';
$lang['delete_ok']             = '%d uzantoj forigiĝis';
$lang['delete_fail']           = '%d malsukcesis esti forigitaj.';
$lang['update_ok']             = 'Tiu uzanto sukcese ĝisdatiĝis';
$lang['update_fail']           = 'Malsukceso okazis por ĝisdatigi tiun uzanton';
$lang['update_exists']         = 'Malsukceso okazis por ŝanĝi la nomon de tiu uzanto: la enmetita nomo (%s) jam ekzistas (ĉiuj aliaj ŝanĝoj estos aplikitaj)';
$lang['start']                 = 'Ekigi';
$lang['prev']                  = 'antaŭe';
$lang['next']                  = 'sekve';
$lang['last']                  = 'laste';
$lang['edit_usermissing']      = 'La elektita uzanto ne troviĝis: tiu nomo povis esti forigita aŭ ŝanĝita aliloke.';
$lang['user_notify']           = 'Avizi uzanton';
$lang['note_notify']           = 'Avizantaj mesaĝoj estos sendataj nur se la uzanto ekhavos novan pasvorton.';
$lang['note_group']            = 'Novaj uzantoj estos aldonitaj al la komuna grupo (%s) se neniu alia estos specifita.';
$lang['note_pass']             = 'La pasvorto estos aŭtomate kreita se la kampo estos lasita malplena kaj \'avizo al uzantoj\' estos ebligita.';
$lang['add_ok']                = 'La uzanto sukcese aldoniĝis';
$lang['add_fail']              = 'Ne eblis aldoni uzanton';
$lang['notify_ok']             = 'Avizanta mesaĝo sendiĝis';
$lang['notify_fail']           = 'La avizanta mesaĝo ne povis esti sendita';
$lang['import_userlistcsv']    = 'Dosiero kun listo de uzantoj (CSV):';
$lang['import_header']         = 'Plej lastaj Import-eraroj';
$lang['import_success_count']  = 'Uzant-importo: %d uzantoj trovataj, %d sukcese importitaj.';
$lang['import_failure_count']  = 'Uzant-importo: %d fiaskis. Fiaskoj estas sube listitaj.';
$lang['import_error_fields']   = 'Nesufiĉe da kampoj, ni trovis %d, necesas 4.';
$lang['import_error_baduserid'] = 'Mankas uzant-id';
$lang['import_error_badname']  = 'Malĝusta nomo';
$lang['import_error_badmail']  = 'Malĝusta retadreso';
$lang['import_error_upload']   = 'Importo fiaskis. La csv-dosiero ne povis esti alŝutata aŭ ĝi estas malplena.';
$lang['import_error_readfail'] = 'Importo fiaskis. Ne eblas legi alŝutitan dosieron.';
$lang['import_error_create']   = 'Ne eblas krei la uzanton';
$lang['import_notify_fail']    = 'Averta mesaĝo ne povis esti sendata al la importita uzanto %s, kun retdreso %s.';
$lang['import_downloadfailures'] = 'Elŝut-eraroj por korektado (CSV)';
